#
# spec file for package hexchat
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Andrey Karepin <egdfree@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           hexchat
Version:        2.12.4
Release:        lp150.1.8
Summary:        A popular and easy to use graphical IRC (chat) client
License:        GPL-2.0+
Group:          Productivity/Networking/IRC
Url:            https://hexchat.github.io/
Source0:        https://dl.%{name}.net/%{name}/%{name}-%{version}-repack.tar.xz
Source1:        hexchat-migrate-sh
Source2:        https://dl.%{name}.net/%{name}/%{name}-%{version}-repack.tar.xz.asc
Source3:        hexchat.keyring
# PATCH-FEATURE-SLE migrate-configuration-from-xchat.patch tyang@suse.com fate#318480 -- replace xchat with hexchat
Patch1:         migrate-configuration-from-xchat.patch
BuildRequires:  dbus-1-devel
BuildRequires:  dbus-1-glib-devel
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel >= 2.34.0
BuildRequires:  gtk2-devel >= 2.24.0
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  iso-codes-devel
BuildRequires:  libcanberra-devel
BuildRequires:  libnotify-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libproxy-devel
BuildRequires:  lua-devel
BuildRequires:  pciutils-devel
BuildRequires:  perl >= 5.8.0
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  perl(ExtUtils::Embed)
Recommends:     %{name}-lang
Recommends:     hwdata
Recommends:     iso-codes
# Provide us as replacement from 1315+
Provides:       xchat = %{version}
Obsoletes:      xchat < %{version}

%description
HexChat is an easy to use graphical IRC chat client for the X Window System.
It allows you to join multiple IRC channels (chat rooms) at the same time,
talk publicly, private one-on-one conversations etc. Even file transfers
are possible.

%package devel
Summary:        Development Files for HexChat
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Recommends:     %{name}-plugins-perl = %{version}
Recommends:     %{name}-plugins-python3 = %{version}

%description devel
This package includes files needed to develop HexChat modules.

%lang_package

%package plugins-perl
Summary:        Plugin for HexChat adds support for Perl scripts
Group:          System/Libraries
%{?libperl_requires}

%description plugins-perl
The HexChat plugin providing the Perl scripting interface.

%package plugins-lua
Summary:        Plugin for HexChat adds support for LUA scripts
Group:          System/Libraries
Requires:       lua

%description plugins-lua
The HexChat plugin providing the LUA scripting interface.

%package plugins-python3
Summary:        Plugin for HexChat adds support for Python3 scripts
Group:          System/Libraries
Provides:       plugins-python = %{version}
Obsoletes:      plugins-python < %{version}

%description plugins-python3
The HexChat plugin providing the Python 3  scripting interface.

%prep
%setup -q
%patch1 -p1

%build
%configure \
	--enable-python=python3 \
	--enable-isocodes

make V=1 %{?_smp_mflags}

%install
install -Dm 0755 %{SOURCE1} %{buildroot}%{_libdir}/hexchat/$(basename %{SOURCE1})
%make_install

# Get rid of libtool archives
find %{buildroot} -type f -name "*.la" -delete -print

%suse_update_desktop_file %{name}

%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc COPYING readme.md
%{_bindir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/hexchat/hexchat-migrate-sh
%{_libdir}/%{name}/plugins/checksum.so
%{_libdir}/%{name}/plugins/fishlim.so
%{_libdir}/%{name}/plugins/sysinfo.so
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.svg
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/dbus-1/services/org.%{name}.service.service
%{_mandir}/man1/%{name}.1%{ext_man}

%files devel
%{_includedir}/%{name}-plugin.h
%{_libdir}/pkgconfig/%{name}-plugin.pc

%files lang -f %{name}.lang

%files plugins-perl
%{_libdir}/%{name}/plugins/perl.so

%files plugins-lua
%{_libdir}/%{name}/plugins/lua.so

%files plugins-python3
%{_libdir}/%{name}/plugins/python.so

%changelog
* Mon Jul  3 2017 astieger@suse.com
- hexchat 2.12.4:
  * fix issue with timers causing ping timeouts
  * fix building against OpenSSL 1.1
  * fix /exec output printing invalid utf8
  * replace doat plugin with an internal command
  * change how tab colors interact with plugins
- verify source signature
* Sat Apr 15 2017 mpluskal@suse.com
- Add dependency on iso-codes and hwdata as hexchat tries to use
  them (boo#1034310)
* Tue Nov 15 2016 tingping@fedoraproject.org
- Update dep versions to match actual requirement
- Remove unused build deps
- Remove no longer needed __DATE__ workaround
* Mon Oct 31 2016 tchvatal@suse.com
- Version update to 2.12.3:
  * various small bugfixes in the 2.12 series
  * Add LUA scripting support
- Drop patch hexchat-python3.patch
* Mon Sep  5 2016 tyang@suse.com
- Modified migrate-configuration-from-xchat.patch
  Add hexchat-migrate-sh
  Realizing the migration job with shell script(bnc#989961)
* Thu Jul 28 2016 tyang@suse.com
- Modified migrate-configuration-from-xchat.patch.
  To realize the migration of servlist.conf file.(bnc#989961)
* Thu May  5 2016 tyang@suse.com
- Add migrate-configuration-from-xchat.patch
  Fate#318480:replace xchat with hexchat,automaticly migrate
  settings from xchat:
  http://hexchat.readthedocs.io/en/latest/faq.html#how-do-i-migrate-my-settings-from-xchat
* Mon Apr 18 2016 nemysis@openSUSE.org
- Remove non existent configure --enable-minimal-flags and --enable-ntlm
* Tue Apr  5 2016 tchvatal@suse.com
- Provide/Obsolete xchat to ensure those that do not have patterns
  containing hexchat to migrate to it.
* Mon Mar 21 2016 tchvatal@suse.com
- Version update to 2.12.0:
  * add support for IRCv3.2
  * add cap 3.2
  * add sasl 3.2
  * add chghost
  * add cap-notify
  * add support for twitch.tv/membership cap
  * add support for SNI (Server Name Indication)
  * add ability to do DnD reordering in some settings dialogs
  * add option to disable middle-click closing tabs
  * rewrite sysinfo plugin
  * change formatting, unified across platforms
  * fix handling unsupported CPU arch on unix
  * rewrite identd plugin
  * add ability to change port
  * fix handling multiple connections
  * fix threading issues
  * rewrite checksum plugin
  * fix support for very large files
  * remove openssl dependency
  * remove DH-{AES,BLOWFISH} mechanisms (insecure)
  * remove “IRC” encoding, replaced with UTF-8
  * remove “System Default” encoding, replaced with UTF-8
  * remove configure option to disable ipv6
  * remove msproxy and socks5 library support (unused)
  * change tab-complete to favor other user nicks over own
  * change url detection to support unicode
  * change decoding to not attempt ISO-8859-1 fixing corruption
  * change pluginpref to escape values
  * change installer on Windows to not overwrite gtkrc file
  * fix numerous crashes (but not #600)
  * fix crash on printing very long lines
  * fix crash on failing to open log file
  * fix crash when using unsorted userlist
  * fix crash when timestamp format set to nothing
  * fix crash when tab-completeing long strings
  * fix crash with long values in pluginpref API
  * fix various other unsafe string handling throughout
  * fix poor performance with nick indent enabled
  * fix fishlim plugin handling networks with server-time
  * fix logging hostname of users in new queries
  * fix Key Press event sending non-UTF-8 text to plugins
  * fix VERSION response on windows 10
  * fix get_info(‘win_ptr’) from python
  * fix running portable-mode from another directory
  * fix duplicate timestamps on selection
  * fix –cfgdir argument
  * fix mode-button text being cut off
  * fix scrollback timestamps with server-time
  * fix url handler accepting quoted paths with spaces
  * fix using correct encoding when jumping networks
  * improve DCC handling large files
  * improve python detection in configure
  * improve scrollback file handling (corruption, line endings)
  * improve build options on unix to be more secure
  * update translations
  * update network list
- Use python3 not python2
  * Add patch hexchat-python3.patch
* Mon Mar 21 2016 tchvatal@suse.com
- As we build only on sle12+ and no non-suse distro the conditionals
  from previous commit do not make much sense
* Tue Feb 23 2016 nemysis@openSUSE.org
- Change URL
- Remove BuildRequires for fdupes, not need for it
- Use check for openSUSE %%if 0%%{?suse_version}
- Add BuildRequires for hicolor-icon-theme
- Add BuildRoot for older openSUSE versions
- Use %%{name} instead of hexchat
* Thu Jan 15 2015 tchvatal@suse.com
- Version bump to 2.10.2:
  * verify hostnames of certificates
  * use more secure openssl options (No SSLv2/3)
  * detect utf8 urls in chat
  * fix using multiple client certs at the same time
  * fix checking for Perl on some distros
  * fix friends list not properly updating
  * fix building with format-security
  * fix more non-ascii path issues on Windows
  * fix opening utf8 urls on Windows and OSX
  * update deps on Windows
  * update translations
- Remove the asneeded.diff as it seems not to be needed, builds without
  and perl is linked well.
* Sat Sep 13 2014 nemysis@gmx.ch
- Version bump to 2.10.1
  * add configure check for python 3.4
  * improve spell check handling apostrophes
  * disable unsupported tray feature on Elementary OS
  * disable installing on Vista (would just crash on x64)
  * fix possible crash in banlist
  * fix some crashes in pluginpref API
  * fix crash in spell check
  * fix notify list being sent to wrong networks
  * fix scrolling the chanview on Unix
  * fix building plugin support on some platforms (OS X 10.8)
  * fix FiSHLiM decryption when identify-msg is enabled
  * fix expanding ~user on Unix
  * fix missing license files on Windows
  * fix silent installer on Windows
  * update translations
  * update network list
  * update Python versions on Windows
* Thu Aug 28 2014 fcrozat@suse.com
- Disable BuildRequires libntlm-devel on SLE12.
* Tue Jul 22 2014 mls@suse.de
- when testing for perl, -lperl has to come last because of
  SUSE_ASNEEDED being set
  new patch: asneeded.diff
* Fri Jun 13 2014 tchvatal@suse.com
- Version bump to 2.10.0:
  * fix SASL on InspIRCd networks
  * fix building on OpenBSD
  * fix crash when using invalid timestamps on Windows
  * fix Lag Meter reporting invalid numbers
  * fix drag and drop on User List/Channel Switcher
  * fix various Unicode issues on Windows
  * add fullscreen display mode
  * add /getbool command
  * add support for userhost-in-names capability
  * add –command command line flag on Windows
  * add message parameter to /query
  * add help messages to user commands
  * add plugin_pref to Perl
  * add regex search to the Channel List on Windows
  * add option to hide nick change messages
  * redesign various settings windows (notably key bindings)
  * render colors and attributes in the Input Box and Topic Bar
  * bind middle-click to close tabs
  * build the GTK+ PixBuf theme engine on Windows
  * change /list to open the Channel List window
  * change the format key bindings are stored in (will convert automatically)
  * enable italics
  * rewrite /dns adding support for Windows and replacing the plugin
  * rebrand the Perl plugin
  * replace the Search window with a Search Bar
  * replace Text Box transparency with full window transparency (may come back)
  * remove all deprecated GTK+ usage
  * remove all direct use of X11, fixing XWayland support
  * hide unsupported channel modes from the Topic Bar
  * improve spell check (handle contractions)
  * improve rendering and selection in the Text Box
  * improve OS X integration (custom theme, app menu, dock icon, spell check, app bundle, key bindings)
  * improve the Windows installer (downloads requirements when ran)
  * update Visual Studio to 2013
  * update Perl to 5.20 on Windows
  * update Python to 3.4 on Windows
  * update OpenSSL on Windows to fix “Heartbleed”
  * update translations
- Adapt few dependencies to match reality
- Update configure switches to comply with upstream
- Make the build verbose
* Wed May 21 2014 tchvatal@suse.com
- Cleanup with spec-cleaner.
* Mon Sep 30 2013 tchvatal@suse.com
- Do not put date into binary to avoid needless rebuilds.
* Mon Sep 30 2013 tchvatal@suse.com
- Add missing defattr on the devel package.
* Mon Sep 30 2013 tchvatal@suse.com
- Add more deps
- Adjust configure a bit
- Utilize devel package as we have .h and .pc files.
* Mon Sep 30 2013 tchvatal@suse.com
- Fix new files in the list.
* Mon Sep 30 2013 tchvatal@suse.com
- Version bump to 2.9.6.1:
  * fixes some utilities causing crash #740
  * redesign edit window in network list
  * rename favorites to autojoin
  * improve url detection yet again (this time w/ more ipv6!)
  * implement /exec -o on Windows
  * improvements to the dcc window
  * improvements to sysinfo on unix, including -e to print info instead of saying
  * add support for BLOWFISH, AES, and EXTERNAL SASL mechanisms
  * add reload command and button in plugingui
  * add support for server-time and znc.in/server-time[-iso] capabilities
  * add attributes to hook_print/server and emit_print for information such as server-time
  * add support for QuakeNet’s challangeauth
  * add chanopt for stripping colors
  * add copy option to banlist entries
  * add autoconnect option to context menu of networks
  * add option for omitting alerts while window is focused
  * add python3 support along with various bugfixes
  * add libcanberra support on unix
  * add tracking of users accounts
  * add %%u to userlist popups for accounts
  * add channelkey to channel lists in plugin api
  * add MONITOR support for the friends list
  * add QUIET and UNQUIET commands
  * add support for the away-notify, account-notify, and extended-join capabilities
  * add notifications for friends away status (requires away-notify)
  * add events for quiet, unquiet, and quietlist
  * add Ctrl+N (New Server Window) keybinding
  * add ctrl+home/end keybinding for scrolling to top/bottom
  * add theme manager to unix build system
  * fix compilation on FreeBSD
  * fix running as root
  * fix splitting ctcps and notices
  * fix alerts and scrollback chanopts
  * fix crash when attaching/detaching tabs
  * fix sending limited channel messages (op messages) to the wrong tab
  * change /load -e to load from config dir
  * remove Ctrl+L (Clear Text) keybinding
  * remove custom sound applications
  * remove away announce, replaced by away-notify on supported servers. (alternative python script)
  * update network list
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Thu Aug 22 2013 egdfree@opensuse.org
- update spec (add libsexy-devel in BuildRequires)
* Thu Apr 25 2013 egdfree@opensuse.org
- initial
  * fix Checksum plugin with DCC download directory set
  * fix false positives with Update Checker
  * fix sound directory option on Unix
  * fix loading custom icons
  * fix tray icon not reappearing if the tray crashes
  * fix restoring maximized windows from tray
  * fix /QUERY -nofocus
  * fix reconnecting to channels with keys
  * fix compilation on FreeBSD
  * fix showing the join dialog when autojoining channels
  * fix Plugin-Tray menu not closing on Windows
  * fix close dialog minimizing to tray before selection
  * fix Python plugin compilation on Ubuntu 13.04
  * fix Theme Manager crashing with read-only files
  * fix channel tree indentation without server tab or with icons
  * add auto-away support to Plugin-Tray
  * add Plugin-Tray option to disable blinking
  * add option to always show notices on current tab
  * add support for notification filtering in GNOME 3.8
  * add support for channel keys in URLs
  * add option to color nicks in the user list the same way as in the chat area
  * add ability to automatically switch to last activity on change-page hotkey
  * add ability to save divider position between combined user list and channel tree
  * add global real name option to Preferences
  * add Safe Mode shortcut to the Start Menu group on Windows
  * add helpful links to the setup wizard on Windows
  * make the source tree compliant with Debian policies
  * install SVG icon on Unix
  * enable Plugin-Tray menu on Windows
  * enable IPv6 by default on Unix
  * show /WHOIS response on current tab by default
  * redesign the Ban List window to show invites, bans, exemptions and quiets
  * make user list icons slightly smaller
  * close all utility windows with the Esc key
  * improve URL and username detection in the chat area
  * make /JOIN focus the existing channel if already joined
  * change default DCC download directory to ~/Downloads on Unix
  * allow Plugins and Scripts utility to be opened in a tab
  * only beep when the HexChat window is not active
  * use the certs subfolder of the config folder for loading custom certificates
  * disable tray icon when using Unity
  * remove Lua and Tcl
  * remove HexTray in favor of built-in Plugin-Tray
  * remove installer theming on Windows
  * cease support for Perl 5.12 and 5.14 on Windows
  * rebuild every dependency with Visual C++ on Windows
  * stop using the WDK on Windows and depend on the Visual C++ Redistributable
  * update GTK+ to 2.24 on Windows
  * update default text events
  * update translations
  * update the network list
